PeakUtils
=========

.. image:: https://zenodo.org/badge/102883046.svg
   :target: https://zenodo.org/badge/latestdoi/102883046

This package provides utilities related to the detection of peaks on 1D data.
Includes functions to estimate baselines, finding the indexes of peaks in the data
and performing Gaussian fitting or centroid computation to further increase the
resolution of the peak detection.

The documentation is available at http://pythonhosted.org/PeakUtils .

Installation
------------

To install PeakUtils from the source package, run:

.. code-block:: bash

    python setup.py install

PeakUtils targets Python 2.7+ and depends on numpy, scipy, and optionally on
matplotlib.

Contribute
----------

- Source Code: https://bitbucket.org/lucashnegri/peakutils
- Issues: https://bitbucket.org/lucashnegri/peakutils/issues
- Direct contact: Lucas Hermann Negri - lucashnegri <at> gmail.com

License
-------

The project is licensed under the MIT license.
